@@ -4,7 +4,7 @@
 # License: MIT License
 from __future__ import unicode_literals
 
-version = (0, 6, 0)  # also update VERSION in setup.py
+version = (0, 6, 2)  # also update VERSION in setup.py
 VERSION = "%d.%d.%d" % version
 __version__ = VERSION
 __author__ = "mozman <mozman@gmx.at>"
@@ -20,7 +20,7 @@ from .tags import dxf_info
 from .tags import TagIterator
 from .importer import Importer
 from .const import DXFStructureError, DXFVersionError
-
+from .zipmanager import ctxZipReader
 
 def new(dxfversion='AC1009'):
     """Create a new DXF drawing.
@@ -61,18 +61,27 @@ def readfile(filename):
     """
     if not is_dxf_file(filename):
         raise IOError("File '{}' is not a DXF file.".format(filename))
-    try: # is it ascii code-page encoded?
+    try:  # is it ascii code-page encoded?
         return readfile_as_asc(filename)
-    except UnicodeDecodeError: # try unicode and ignore errors
+    except UnicodeDecodeError:  # try unicode and ignore errors
         return readfile_as_utf8(filename, errors='ignore')
 
-#TODO: write integration test for reading 'utf-8' encoded files
+
+def readzip(zipfile, filename=None):
+    """ Reads the DXF file *filename* from *zipfile* or the first DXF file in *zipfile* if *filename* is *None*.
+    """
+    with ctxZipReader(zipfile, filename) as zipstream:
+        dwg = read(zipstream)
+        dwg.filename = zipstream.dxf_file_name
+    return dwg
+
+
 def readfile_as_utf8(filename, errors='strict'):
     """Read DXF drawing from file *filename*, expects an 'utf-8' encoding.
     """
     return _read_encoded_file(filename, encoding='utf-8', errors=errors)
 
-#TODO: write integration test for reading 'ascii-code-page' encoded files
+
 def readfile_as_asc(filename):
     """Read DXF drawing from file *filename*, expects an ascii code-page encoding.
     """
@@ -82,6 +91,7 @@ def readfile_as_asc(filename):
         return info.encoding
     return _read_encoded_file(filename, encoding=get_encoding())
 
+
 # noinspection PyArgumentList
 def _read_encoded_file(filename, encoding='utf-8', errors='strict'):
     if options.debug:
@@ -91,9 +101,9 @@ def _read_encoded_file(filename, encoding='utf-8', errors='strict'):
     dwg.filename = filename
     return dwg
 
+
 # noinspection PyArgumentList
 def is_dxf_file(filename):
     with io.open(filename, errors='ignore') as fp:
         reader = TagIterator(fp)
-        return tuple(next(reader) for _ in range(2)) == ((0, 'SECTION'), (2, 'HEADER'))
-
+        return next(reader) == (0, 'SECTION')
